
College Board Celebrity and Data Labs
=====================================

.. |Celebrity Lab| raw:: html

   <a href="https://apcentral.collegeboard.org/pdf/ap-computer-science-a-celebrity-lab-student-guide.pdf" target="_blank" style="text-decoration:underline">Celebrity Lab</a>

.. |Data Lab| raw:: html

   <a href="https://apcentral.collegeboard.org/pdf/ap-computer-science-a-data-lab-student-guide.pdf" target="_blank">Data Lab</a>


The new AP CSA Labs released in 2019, the |Celebrity Lab| (Activity 1-2) and the |Data Lab| (Activity 1-2), are for students to practice writing classes. Each of these labs have further activities that you will finish after Unit 7. The teacher guide and the code files are available in the AP Course Audit Portal. This page will eventually include tips to complete the labs.
